#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
lora03.py

20160604
"""

import sys
from PyQt4 import Qt, QtGui, QtCore
from ui_lora import Ui_LoraGUI
import serial
from time import sleep
from crc16b import calcByte,calcString,hexCRC,checkModbusWithCrc,readHex

class LoraGUI(QtGui.QWidget, Ui_LoraGUI):
	def __init__(self, parent=None, f=QtCore.Qt.WindowFlags()):
		QtGui.QWidget.__init__(self, parent, f)
		self.setupUi(self)
		
		if len( sys.argv ) == 2 :
			szPort = sys.argv[1]
			nBauds = 9600
		else :
			if len( sys.argv ) == 3 :
				szPort = sys.argv[1]
				nBauds = int(sys.argv[2])
			else :
				szPort = "/dev/ttyUSB0"
				nBauds = 9600

		port = szPort
		baudrate = nBauds
		
		try: 	
			self.ser = serial.Serial(
				port,
				baudrate,
				timeout=0,
				parity=serial.PARITY_NONE,
				stopbits=serial.STOPBITS_TWO,
				bytesize=serial.EIGHTBITS
			)
		except serial.SerialException as e:
			print szPort, " port is not connected"
			self.close()
			sys.exit(-1)
		szTitle = "%s @%d" % (port,baudrate)	
		self.setWindowTitle(szTitle)
		self.connect(self.lineEditStr, Qt.SIGNAL("textChanged(QString)"), self.funcStr2Hex)
		self.connect(self.lineEditHex, Qt.SIGNAL("textChanged(QString)"), self.funcHexChanged)
		self.connect(self.radioButtonWithoutCRC, Qt.SIGNAL("toggled(bool)"), self.funcRemoveCRC)
		self.connect(self.radioButtonAddCRC, Qt.SIGNAL("toggled(bool)"), self.funcAddCRC)
		self.connect(self.btTxRx, Qt.SIGNAL("clicked()"), self.btTxRxPressed)
		self.bWithCRC = False

	def funcAddCRC(self,b):
		if b:
			self.bWithCRC = True

	def funcRemoveCRC(self,b):
		if b:
			self.bWithCRC = False
			
	def funcHexChanged(self,szHex):
		nSzHex = len(szHex)
		if nSzHex % 2 == 0:
			i = 0
			szNum = ""
			while ( i < nSzHex ):
				szNum += "%c%c" % (str(szHex[i])[0],str(szHex[i+1])[0])
				nByte = int (szNum,16)
				i += 2
			hCRC = hexCRC(szNum)
			szAddedCRC="%02X%02X"%(hCRC>>8,hCRC&0xFF)
			self.lineEditCRC.setText(szAddedCRC)
			self.lineEditHex.setText(szNum)

	def funcStr2Hex(self,szStr):
		st = ""
		for ch in str(szStr):
			st += "%02X" % ord(ch)					
		self.lineEditHex.setText(st)
		
	def btTxRxPressed(self):
		if self.lineEditHex.text().length() % 2 == 0:
			szHtml = QtCore.QString("")
			nSzHex = self.lineEditHex.text().length() / 2
			if self.bWithCRC:
				nSzHex += 2
			st = "%02X" % nSzHex	
			szHtml += "<font color=\"red\">" + st + "</font>"
			szHtml += "<font color=\"orange\">" + self.lineEditHex.text() + "</font>"
			if self.bWithCRC:
				szHtml += "<font color=\"red\">" + self.lineEditCRC.text() + "</font>"
			
			self.plainTextEdit.appendHtml(szHtml)
	
	def __del__(self):
		self.ser.close()

if __name__ == '__main__':

	app = QtGui.QApplication(sys.argv)
	window = LoraGUI()
	window.show()

	sys.exit(app.exec_())
